@@ -252,6 +252,10 @@ void binding_activate(Binding_t *self) {
     binding_exec(self);
     break;
 
+  case XC_ACTION_WAIT:    
+    binding_wait(self);
+    break;
+
   case XC_ACTION_GROUP:
     binding_group(self);
     break;
@@ -297,22 +301,22 @@ int binding_wait_event(Binding_t *self) {
     }
 
     FD_ZERO(&in);
-    FD_SET(xc->conn_fd, &in);
+    FD_SET(xc->connection, &in);
 
     if (ignore_delay) {
-        return select(xc->conn_fd + 1, &in, 0, 0, timeout_tv);
+        return select(xc->connection + 1, &in, 0, 0, timeout_tv);
     } else {
         if (delay_tv
-            && select(xc->conn_fd + 1, &in, 0, 0, delay_tv)) {
+            && select(xc->connection + 1, &in, 0, 0, delay_tv)) {
             return 1;
         }
 
         if(!xc->popup->mapped)
             popup_show(xc->popup);
 
-        if (!FD_ISSET(xc->conn_fd, &in))
-            FD_SET(xc->conn_fd, &in);
-        return select(xc->conn_fd + 1, &in, 0, 0, timeout_tv);
+        if (!FD_ISSET(xc->connection, &in))
+            FD_SET(xc->connection, &in);
+        return select(xc->connection + 1, &in, 0, 0, timeout_tv);
     }
 }
 
@@ -383,7 +387,7 @@ void binding_enter(Binding_t *self) {
 	    keyspec = key_to_str(key);
 	    sprintf(xc->popup->text, "%s %s: no binding", path, keyspec);
 	    popup_show(xc->popup);
-	    xc->popup->timeout = xc->delay;
+	    xc->popup->timeout = (xc->hold == -1) ? xc->delay : xc->hold;
 
 	    if (xc->debug) {
 	      printf(" -> %s %s: no binding\n", path, keyspec);
@@ -515,6 +519,21 @@ void binding_group(Binding_t *self) {
   }
 }
 
+void binding_wait(Binding_t *self) {
+  char *command = self->argument;
+
+  XUngrabKeyboard(xc->display, CurrentTime);
+  XFlush(xc->display);
+
+  system(command);
+
+  if (self->parent != xc->root)
+    XGrabKeyboard(xc->display, DefaultRootWindow(xc->display),
+		  True, GrabModeAsync, GrabModeAsync, CurrentTime);
+
+  XFlush(xc->display);
+}
+
 void binding_exec(Binding_t *self) {
   pid_t pid;
   char *command = self->argument;
