@@ -8,7 +8,8 @@
 #define XC_ACTION_EXEC     4
 #define XC_ACTION_GROUP    5
 #define XC_ACTION_LOAD     6
-#define XC_NUM_ACTIONS     7
+#define XC_ACTION_WAIT     7
+#define XC_NUM_ACTIONS     8
 
 #define XC_ABORT_AUTO 1
 #define XC_ABORT_MANUAL 0
@@ -21,7 +22,9 @@ typedef struct XChainKeys {
   int debug;
   unsigned int timeout;
   unsigned int delay;
-  int conn_fd;
+  unsigned int hold;
+  int connection;
+  char *position;
   char *config;
   int reload;
   struct Popup *popup;
